#include <cassert>

#include <cstdlib>
using std::atoi;

#include <iostream>
using std::cerr;
using std::endl;

#include <fstream>
using std::ofstream;

#include <algorithm>
using std::max;

#include "routines.h"

int main(int argc, char* argv[])
{
	assert(argc == 2);
	const size_t L = atoi(argv[1]);
	assert(L != 0);
	initialize(L);
	cerr << endl << "Polymer of length " << thePolymer.length() 
	             << " (" << thePolymer.size() << " monomers)" << endl;

	// Thermalization
	const unsigned int tau0 = max(size_t(1),thePolymer.size()/3);	
	const unsigned int thermalization = 50*tau0;

	for (size_t i = 0; i < thermalization; ++i)
		update();

	// Sampling
	const unsigned int binsize = 250;
	const unsigned int measurements = 500;

	ofstream fout("r2.bins.dat",std::ios::app);
	for (size_t i = 0; i < measurements; ++i)
	{
		if (i%25 == 0)
			cerr << "Computing bin# " << i << endl;
		for (size_t j = 0; j < binsize; ++j)
		{
			for (size_t k = 0; k < tau0; ++k)
				update();
			measure();
		}
		dump(i+1,fout);
	}
	fout << endl << endl;
	fout.close();
	return 0;
}
